/***********************************************************************/
/*                                                                     */
/*  FILE        :Main.c or Main.cpp                                    */
/*  DATE        :Fri, Apr 28, 2017                                     */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :                                                      */
/*                                                                     */
/*  NOTE:THIS IS A TYPICAL EXAMPLE.                                    */
/*                                                                     */
/***********************************************************************/

/*******************************************************************************
Includes <System Includes> , "Project Includes"
*******************************************************************************/
//#include "typedefine.h"
#include "platform.h"
#include "r_flash_rx_if.h"
#include "r_flash_rx_config.h"


/*******************************************************************************
Macro definitions
*******************************************************************************/
#define ACCESS_DF_EN_0000_0015BLOCK (0x0001)                    /* 0000-0015 block read and P/E enable */

#define CF_TABLE_SIZE               (ROM_PROGRAM_SIZE_LARGE)    /* data table size for erase/write code flash area */
#define CF_WRITE_SIZE               (ROM_PROGRAM_SIZE_LARGE)    /* write data size for code flash */
#define DF_WRITE_SIZE               (FLASH_DF_BLOCK_SIZE)       /* write data size fro data flash */

/*******************************************************************************
typedef definitions
*******************************************************************************/
typedef enum
{
    TARGET_CODE_FLASH = 0,
    TARGET_DATA_FLASH
} flash_target_t;

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void main(void);
flash_err_t er_wr_flash( flash_access_window_config_t access_info,
                        flash_block_address_t block_start_adr,
                        uint32_t erase_num_blocks,
                        uint32_t src_adr,
                        uint32_t dest_adr,
                        uint32_t write_size );

/*******************************************************************************
* Constant Definition 
*******************************************************************************/
#pragma address cf_data_table = 0xFFFFC000 /* FLASH_CF_BLOCK_7 */

/* for erase/write area of code flash */
const uint8_t cf_data_table[CF_TABLE_SIZE] =
{
    0xFF, 0xFE, 0xFD, 0xFC, 0xFB, 0xFA, 0xF9, 0xF8,
    0xF7, 0xF6, 0xF5, 0xF4, 0xF3, 0xF2, 0xF1, 0xF0,
    0xEF, 0xEE, 0xED, 0xEC, 0xEB, 0xEA, 0xE9, 0xE8,
    0xE7, 0xE6, 0xE5, 0xE4, 0xE3, 0xE2, 0xE1, 0xE0,
    0xDF, 0xDE, 0xDD, 0xDC, 0xDB, 0xDA, 0xD9, 0xD8,
    0xD7, 0xD6, 0xD5, 0xD4, 0xD3, 0xD2, 0xD1, 0xD0,
    0xCF, 0xCE, 0xCD, 0xCC, 0xCB, 0xCA, 0xC9, 0xC8,
    0xC7, 0xC6, 0xC5, 0xC4, 0xC3, 0xC2, 0xC1, 0xC0,
    0xBF, 0xBE, 0xBD, 0xBC, 0xBB, 0xBA, 0xB9, 0xB8,
    0xB7, 0xB6, 0xB5, 0xB4, 0xB3, 0xB2, 0xB1, 0xB0,
    0xAF, 0xAE, 0xAD, 0xAC, 0xAB, 0xAA, 0xA9, 0xA8,
    0xA7, 0xA6, 0xA5, 0xA4, 0xA3, 0xA2, 0xA1, 0xA0,
    0x9F, 0x9E, 0x9D, 0x9C, 0x9B, 0x9A, 0x99, 0x98,
    0x97, 0x96, 0x95, 0x94, 0x93, 0x92, 0x91, 0x90,
    0x8F, 0x8E, 0x8D, 0x8C, 0x8B, 0x8A, 0x89, 0x88,
    0x87, 0x86, 0x85, 0x84, 0x83, 0x82, 0x81, 0x80
};

#pragma section 

/* writing data for data flash */
const uint8_t df_write_data[DF_WRITE_SIZE] =
{
    0x98, 0x76, 0x54, 0x32, 0x10, 0xFE, 0xDC, 0xAB, 0x02, 0xE0, 0x04, 0xC0, 0x06, 0xA0, 0x08, 0x80,
    0xF1, 0xD3, 0xB5, 0x97, 0x79, 0x5B, 0x3D, 0x1F, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88,
    0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF, 0x00, 0x01, 0x23, 0x45, 0x67, 0x89, 0xAB, 0xCD, 0xEF,
    0x08, 0x19, 0x2A, 0x3B, 0x4C, 0x5D, 0x6E, 0x7F, 0xF7, 0xE6, 0xD5, 0xC4, 0xB3, 0xA2, 0x91, 0x80,
    0x98, 0x76, 0x54, 0x32, 0x10, 0xFE, 0xDC, 0xAB, 0x02, 0xE0, 0x04, 0xC0, 0x06, 0xA0, 0x08, 0x80,
    0xF1, 0xD3, 0xB5, 0x97, 0x79, 0x5B, 0x3D, 0x1F, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88,
    0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF, 0x00, 0x01, 0x23, 0x45, 0x67, 0x89, 0xAB, 0xCD, 0xEF,
    0x08, 0x19, 0x2A, 0x3B, 0x4C, 0x5D, 0x6E, 0x7F, 0xF7, 0xE6, 0xD5, 0xC4, 0xB3, 0xA2, 0x91, 0x80

};

/* writing data for code flash */
uint8_t cf_write_data[CF_WRITE_SIZE] =
{
    0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
    0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F,
    0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
    0x18, 0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F,
    0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
    0x28, 0x29, 0x2A, 0x2B, 0x2C, 0x2D, 0x2E, 0x2F,
    0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37,
    0x38, 0x39, 0x3A, 0x3B, 0x3C, 0x3D, 0x3E, 0x3F,
    0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47,
    0x48, 0x49, 0x4A, 0x4B, 0x4C, 0x4D, 0x4E, 0x4F,
    0x50, 0x51, 0x52, 0x53, 0x54, 0x55, 0x56, 0x57,
    0x58, 0x59, 0x5A, 0x5B, 0x5C, 0x5D, 0x5E, 0x5F,
    0x60, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67,
    0x68, 0x69, 0x6A, 0x6B, 0x6C, 0x6D, 0x6E, 0x6F,
    0x70, 0x71, 0x72, 0x73, 0x74, 0x75, 0x76, 0x77,
    0x78, 0x79, 0x7A, 0x7B, 0x7C, 0x7D, 0x7E, 0x7F
};


/*******************************************************************************
* Function Name: main
* Description  : Main program
* Arguments    : none
* Return Value : none
*******************************************************************************/
void main(void)
{
    flash_err_t err;                            /* error check */
    flash_access_window_config_t access_info;
    
    /* initialize the Flash FIT module */
    err = R_FLASH_Open();
    if ( FLASH_SUCCESS != err )
    {
        goto FLASH_ERR;
    }
    else
    {
        /* Do nothing */
    }

    /* code flash memory */
    access_info.read_en_mask = NULL;
    access_info.write_en_mask = NULL;
    err = er_wr_flash(access_info, FLASH_CF_BLOCK_7, 1, (uint32_t)cf_write_data, FLASH_CF_BLOCK_7, CF_WRITE_SIZE);

    if ( FLASH_SUCCESS != err )
    {
        goto FLASH_ERR;
    }
    else
    {
        PORTH.PODR.BIT.B2 = 1;      /* Turn on D3 */
    }

    /* data flash memory */
    access_info.read_en_mask = ACCESS_DF_EN_0000_0015BLOCK;     /* allow Read access */
    access_info.write_en_mask = ACCESS_DF_EN_0000_0015BLOCK;    /* allow Erase/Write access */
    err = er_wr_flash(access_info, FLASH_DF_BLOCK_0, 1, (uint32_t)df_write_data, FLASH_DF_BLOCK_0, DF_WRITE_SIZE);

    if ( FLASH_SUCCESS != err )
    {
        goto FLASH_ERR;
    }
    else
    {
        PORTH.PODR.BIT.B3 = 1;      /* Turn on D4 */
    }

    /* normal end */
    while(1);

FLASH_ERR:
    while(1);
}

/*******************************************************************************
* Function Name: er_wr_flash
* Description  : Code/Data flash access
* Arguments    : flash_access_window_config_t access_info
*                   - access window area
*               flash_block_address_t block_start_adr
*                   - block start address
*               uint32_t erase_num_blocks
*                   - number of erasing blocks
*               uint32_t src_adr
*                   - source address for writing
*               uint32_t dest_adr
*                   - destination address for writing
*               uint32_t write_size
*                   - size of writing
* Return Value : flash_err_t
*******************************************************************************/
flash_err_t er_wr_flash( flash_access_window_config_t access_info,
                        flash_block_address_t block_start_adr,
                        uint32_t erase_num_blocks,
                        uint32_t src_adr,
                        uint32_t dest_adr,
                        uint32_t write_size )
{
    uint32_t cnt;                               /* loop counter */
    uint32_t block_cnt;                         /* loop counter */
    uint8_t *src_ptr;
    uint8_t *dest_ptr;
    flash_err_t err;                            /* error check */ 
    flash_res_t result;                         /* Result type for certain operations */
    flash_target_t target_flash;

    /* data falsh area */
    if ( (FLASH_DF_BLOCK_0 <= block_start_adr) && (FLASH_DF_BLOCK_INVALID > block_start_adr) )
    {
        /* allow reading/writing to data flash blocks */
        err = R_FLASH_Control(FLASH_CMD_ACCESSWINDOW_SET, (void *)&access_info);
        target_flash = TARGET_DATA_FLASH;
    }
    else
    {
        err = FLASH_SUCCESS;
        target_flash = TARGET_CODE_FLASH;
    }

    /* normal end */
    if ( FLASH_SUCCESS == err )
    {
        /* erase code/data flash blocks */
        err = R_FLASH_Erase(block_start_adr, erase_num_blocks);

        /* normal end */
        if ( FLASH_SUCCESS == err )
        {
            /* data flash */
            if ( TARGET_DATA_FLASH == target_flash )
            {
                /* blank check data flash blocks */
                for ( block_cnt=0; block_cnt<erase_num_blocks; block_cnt++ )
                {
                    for ( cnt=0; cnt<DF_ERASE_BLOCK_SIZE/DF_PROGRAM_SIZE_SMALL; cnt++ )
                    {
                        err = R_FLASH_BlankCheck(block_start_adr+DF_PROGRAM_SIZE_SMALL*cnt, BLANK_CHECK_SMALLEST, &result);
                        /* error occurred */
                        if ( (FLASH_SUCCESS != err) || (FLASH_RES_BLANK != result) )
                        {
                            block_cnt = erase_num_blocks;
                            break;
                        }
                        else
                        {
                            /* Do nothing */
                        }
                    }
                }
            }
            else
            {
                result = FLASH_RES_BLANK;
            }

            /* normal end */
            if ( (FLASH_SUCCESS == err) && (FLASH_RES_BLANK == result) )
            {
                /* write data to code/data flash memory */
                err = R_FLASH_Write(src_adr, dest_adr, write_size);

                /* normal end */
                if ( FLASH_SUCCESS == err )
                {
                    src_ptr = (uint8_t *)src_adr;

                    /* code flash */
                    if ( TARGET_CODE_FLASH == target_flash )
                    {
                        dest_ptr = (uint8_t *)(dest_adr | 0xFF000000);
                    }
                    else
                    {
                        dest_ptr = (uint8_t *)dest_adr;
                    }

                    /* verify code/data flash memory */
                    for ( cnt=0; cnt<write_size; cnt++ )
                    {
                        /* not matching ? */
                        if ( (*(src_ptr+cnt)) != (*(dest_ptr+cnt)) )
                        {
                            err = FLASH_ERR_FAILURE;
                            break;
                        }
                        else
                        {
                            /* Do nothing */
                        }
                    }
                }
                else
                {
                    /* Do nothing */
                }
            }
            else
            {
                err = FLASH_ERR_FAILURE;
            }
        }
        else
        {
            /* Do nothing */
        }
    }
    else
    {
        /* Do nothing */
    }

    return (err);
}
